*************
API Reference
*************

.. toctree::
   :maxdepth: 1

   reference/interface
   reference/decorator
   reference/graph
   reference/serialization
   reference/ontologies
   reference/utility
   reference/settings
